
import Taro, { Component } from '@tarojs/taro'
import { View, Text, Button, Input } from '@tarojs/components'
import { AtInput, AtImagePicker, AtTextarea, Picker, AtModal, AtModalHeader, AtModalContent, AtModalAction } from 'taro-ui'

import CopyrightComponent from '../../component/copyrightComponent/copyrightComponent'
import URL from '../../serviceAPI.config'


import './myDemandSupplyEdit.scss'



class MyDemandSupplyEdit extends Component {

    config = {
        navigationBarTitleText: '供求编辑'
    }
    constructor() {
        super(...arguments)
        this.state = {
            demandingSupplyCate: [{ name: '需求', id: '1' }, { name: '供应', id: '2' }, { name: '人才', id: '3' }], //供求类型选择, 
            demandingSupplyCateSelected: { name: '需求', id: '1' },// 当前供求类型
            demandingSupplyState: [{ name: '上架', id: '1' }, { name: '下架', id: '0' }], // 状态选择
            demandingSupplyStateSelected: { name: '上架', id: '1' },// 当前状态
            title: '',
            contactName: '',
            contactNumber: '',
            contactAddress: '',
            content: '',
            pickerImageUrl: [], // 上传的图片
            ImagesInfo: [],// 后台传回来的图片信息

            isFormCompleted: false,
            isConfirmWindow: false,// 删除提示框
            demandSupplyId: '',// 供求id
            isSave: false,//是否点击保存按钮
            isSaveAndNew: false//是否点击保存新增按钮


        }
    }
    //获取商品信息api GetProductInfo
    getSupplyDemandInfo() {
        Taro.request({
            url: URL.GetSupplyDemandInfo,
            method: 'GET',
            dataType: 'json',
            data: {
                sdID: this.$router.params.sdId,
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'Cookie': 'PFWSSS=' + Taro.getStorageSync('session_id'),
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
            .then(res => {
                console.log('供求详情获取成功', res)
                const selectedType = this.state.demandingSupplyCate.filter(item => item.id == res.data.sdInfo.sd_type)[0]
                const selectedState = this.state.demandingSupplyState.filter(item => item.id == res.data.sdInfo.state)[0]
                const imageFile = res.data.sdInfo.file_path.map(item => { return { url: URL.Base + item.file_path } })
                this.setState({
                    demandSupplyId: res.data.sdInfo.sd_id,
                    demandingSupplyCateSelected: selectedType,
                    title: res.data.sdInfo.sd_title,
                    contactName: res.data.sdInfo.user_name,
                    contactNumber: res.data.sdInfo.user_phone,
                    contactAddress: res.data.sdInfo.user_address,
                    content: res.data.sdInfo.sd_desc,
                    demandingSupplyStateSelected: selectedState,
                    pickerImageUrl: imageFile,
                    ImagesInfo: res.data.sdInfo.file_path,
                })
                Taro.hideLoading()
            }

            )
            .catch(error => {
                console.log('供求详情获取失败', error)
            })
    }



    // uploadDemSup 上传供求 的api
    uploadDemSup({ sd_type = this.state.demandingSupplyCateSelected.id,
        sd_title = this.state.title,
        user_name = this.state.contactName,
        user_phone = this.state.contactNumber,
        user_address = this.state.contactAddress,
        sd_desc = this.state.content,
        state = this.state.demandingSupplyStateSelected.id }) {

        const file_path = [];
        this.state.ImagesInfo.forEach((item) => {
            file_path.push({
                file_name: item.file_name,
                file_size: item.file_size,
                file_path: item.file_path,
                thumb_path: item.thumb_path
            })
        })
        Taro.request({
            url: URL.UploadSupplyDemand,
            method: 'POST',
            dataType: 'json',
            data: {
                action: 2,
                sdInfo: JSON.stringify({
                    sd_id: this.$router.params.sdId,
                    sd_type: sd_type,
                    sd_title: sd_title,
                    user_name: user_name,
                    user_phone: user_phone,
                    user_address: user_address,
                    sd_desc: sd_desc,
                    state: state,
                    file_path: file_path
                })
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'Cookie': 'PFWSSS=' + Taro.getStorageSync('session_id'),
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
            .then(res => {
                console.log('上传供求', res)
                Taro.hideLoading()
                if (res.data.err_msg === 'success') {
                    Taro.showToast({
                        title: '保存成功',
                        icon: 'success',
                        duration: 1000
                    }).then(() => {
                        setTimeout(() => {
                            if (this.state.isSave) {
                                Taro.navigateTo({
                                    url: '/pages/myDemandSupplyEdit/myDemandSupplyEdit?sdId=' + res.data.sd_id
                                })
                            } else if (this.state.isSaveAndNew) {
                                Taro.navigateTo({
                                    url: '/pages/supplyDemandPublish/supplyDemandPublish'
                                })
                            }
                        }, 1000);
                    })
                } else {
                    Taro.showToast({
                        title: res.data.err_msg,
                        icon: 'none',
                        duration: 1500
                    })
                }

            }
            )

    }

    // 上传图片
    onChangeImg(files, operationType, index) {
        const that = this
        if (operationType === 'add') {
            Taro.uploadFile({
                url: URL.UploadDSPorductImage,
                filePath: files[files.length - 1].url,
                name: 'file',
                header: {
                    'content-type': 'multipart/form-data',
                    'Cookie': 'PFWSSS=' + Taro.getStorageSync('session_id'),
                    'X-Requested-With': 'XMLHttpRequest'
                },
                success(response) {
                    const data = JSON.parse(response.data)
                    const imagePath = URL.Base + data.file_path
                    const newPickerImageUrl = that.state.pickerImageUrl.concat({ url: imagePath })
                    const newImageInfo = that.state.ImagesInfo.concat(data)
                    that.setState({
                        pickerImageUrl: newPickerImageUrl,
                        ImagesInfo: newImageInfo
                    })
                    Taro.showToast({
                        title: '上传成功',
                        icon: 'success',
                        duration: 1500
                    })
                }
            })
        }
        if (operationType === 'remove') {
            this.state.ImagesInfo.splice(index, 1) // 删除显示的图片
            this.state.pickerImageUrl.splice(index, 1)// 删除图片param
            that.setState({
                pockerImageUrl: this.state.pickerImageUrl,
                ImagesInfo: this.state.ImagesInfo,
            })
            Taro.showToast({
                title: '删除成功',
                icon: 'success',
                duration: 1500
            })
        }
    }
    // 删除我的供求api
    onDelete({ sdID = 0 }) {
        Taro.request({
            url: URL.DeleteDemandSupply,
            method: 'POST',
            dataType: 'json',
            data: {
                sdID: sdID
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'Cookie': 'PFWSSS=' + Taro.getStorageSync('session_id'),
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
            .then(res => {
                if (res.data.err_msg == 'success') {
                    Taro.showToast({
                        title: '删除成功'
                    }).then(() => {
                        setTimeout(() => {
                            Taro.navigateTo({
                                url: '/pages/supplyDemandPublish/supplyDemandPublish'
                            })
                        }, 1500);
                    })

                } else {

                    Taro.showToast({
                        title: res.data.err_msg,
                        icon: 'none'
                    })
                }
            }
            )
            .catch(error => {

                Taro.showToast({
                    title: '删除失败',
                    icon: 'none'
                })
            })
    }
    // 修改供求类型
    demandingSupplyCate = e => {
        this.setState({
            demandingSupplyCateSelected: this.state.demandingSupplyCate[e.detail.value]
        })
    }
    // 修改供求状态
    demSupplyStateChange = e => {
        this.setState({
            demandingSupplyStateSelected: this.state.demandingSupplyState[e.detail.value]
        })
    }
    //改标题
    titleChange(event) {
        this.setState({ title: event })
    }
    contactNameChange(event) {
        this.setState({ contactName: event })
    }
    contactNumberChange(event) {
        this.setState({ contactNumber: event })
    }
    contactAddressChange(event) {
        this.setState({ contactAddress: event.target.value })
    }
    contentChange(event) {
        this.setState({ content: event.target.value })
    }
    // 上传供求api
    saveButtonHandler() {
        if (this.state.demandingSupplyCateSelected && this.state.title && this.state.contactName && this.state.contactNumber && this.state.content && this.state.demandingSupplyStateSelected) {

            Taro.showLoading({ title: '保存中' }).then(() => {
                this.setState({ isSave: true }, () => {
                    this.uploadDemSup({})
                })
            })

        } else {
            Taro.showToast({
                title: '请填写完表格',
                icon: 'none',
                duration: 1500
            })
        }

    }
    // 上传供求api
    saveAndNewButton() {
        if (this.state.demandingSupplyCateSelected && this.state.title && this.state.contactName && this.state.contactNumber && this.state.content && this.state.demandingSupplyStateSelected) {
            Taro.showLoading({ title: '保存中' }).then(() => {
                this.setState({ isSaveAndNew: true }, () => {
                    this.uploadDemSup({})
                })
            })
        } else {
            Taro.showToast({
                title: '请填写完表格',
                icon: 'none',
                duration: 1500
            })
        }
    }
    goToMyDemSupPage() {
        Taro.navigateTo({
            url: '/pages/mySupplyDemand/mySupplyDemand'
        })
    }
    deleteButtonHandler() {
        this.setState({ isConfirmWindow: true })
    }
    handleWindowModClose() {
        this.setState({ isConfirmWindow: false })
    }
    handleWindowModCancel() {
        this.setState({ isConfirmWindow: false })
    }
    handleWindowConfirm() {
        this.setState({ isConfirmWindow: false })
        this.onDelete({ sdID: this.state.demandSupplyId })
    }


    componentDidMount() {
        // console.log('this.$router.params.sdId',this.$router.params.sdId)
        Taro.showLoading({ title: '加载中' })
        this.getSupplyDemandInfo()
    }
    componentWillReceiveProps(nextProps) {
        console.log(this.props, nextProps)
    }

    componentWillUnmount() { }

    componentDidShow() { }

    componentDidHide() { }

    render() {
        // 提示模态弹窗element
        const modalMessageConfirmElement = <AtModal isOpened={this.state.isConfirmWindow}>
            <AtModalHeader>提示</AtModalHeader>
            <AtModalContent>
                确认删除{this.state.demandSupplyItemName}？
         </AtModalContent>
            <AtModalAction> <Button onClick={this.handleWindowModCancel.bind(this)}>取消</Button> <Button className='orange' onClick={this.handleWindowConfirm.bind(this)}>确定</Button> </AtModalAction>
        </AtModal>

        return (
            <View className='supply-demand'>
                {modalMessageConfirmElement}

                <View className='page-section'>
                    <View>
                        <Picker mode='selector' rangeKey='name' range={this.state.demandingSupplyCate} onChange={this.demandingSupplyCate.bind(this)}>
                            <View className='picker'>
                                <View className='title-box'>
                                    <Text className='title'><Text className='require'>*</Text>供求类型:</Text> <Text className='selected'>{this.state.demandingSupplyCateSelected.name}</Text>
                                </View>

                            </View>
                        </Picker>
                    </View>
                </View>
                <View className='border-box'>
                    <Text className='require'>*</Text><AtInput
                        name='value'
                        title='需求标题：'
                        type='text'
                        value={this.state.title}
                        border={false}
                        onChange={this.titleChange.bind(this)}

                    />
                </View>
                <View className='input-box'>
                    <Text className='require'>*</Text>
                    <AtInput
                        name='value'
                        title='联系人：'
                        type='text'
                        value={this.state.contactName}
                        border={false}
                        onChange={this.contactNameChange.bind(this)}
                    />
                </View>
                <View className='input-box' style='padding:24rpx 0;font-size:32rpx'>
                    <View className='title' style='font-weight:bold;'>
                    <Text style='color:red'>*</Text>
                        <Text>联系电话：</Text>
                    </View>
                    <View style='margin-left:5%;'>
                        <Input name='value'
                            maxLength='11'
                            type='number'
                            value={this.state.contactNumber}
                            onInput={this.handleInputCsultName.bind(this)}
                        /></View>
                </View>
                <View className='demanding-box'>
                    <View className='title-box'>
                        <Text className='title'><Text className='require'></Text>联系地址:</Text>
                    </View>

                    <AtTextarea
                        value={this.state.contactAddress}
                        onChange={this.contactAddressChange.bind(this)}
                        maxlength='200'
                        placeholder='联系地址'
                    />
                </View>
                <View className='demanding-box'>
                    <View className='title-box'>
                        <Text className='title'><Text className='require'>*</Text>需求内容:</Text>
                    </View>
                    <AtTextarea
                        value={this.state.content}
                        onChange={this.contentChange.bind(this)}
                        maxlength='200'
                        placeholder=''
                    />
                </View>
                <View className='img-box'>
                    <View className='title-box'>
                        <Text className='title'>需求图片:</Text>
                        <View className='warn'>(最多4张)</View>
                    </View>

                    <View className='img-container'>
                        <AtImagePicker
                            multiple
                            showAddBtn={this.state.pickerImageUrl.length < 4}
                            files={this.state.pickerImageUrl}
                            onChange={this.onChangeImg.bind(this)}
                            onFail={this.onFail.bind(this)}
                            onImageClick={this.onImageClick.bind(this)}
                        />
                    </View>

                </View>
                <View className='page-section'>

                    <View>
                        <Picker mode='selector' rangeKey='name' range={this.state.demandingSupplyState} onChange={this.demSupplyStateChange}>
                            <View className='picker'>
                                <View className='title-box'>
                                    <Text className='title'> <Text className='require'>*</Text>状态:</Text> <Text className='selected'>{this.state.demandingSupplyStateSelected.name}</Text>
                                </View>

                            </View>
                        </Picker>
                    </View>
                </View>

                <View className='button-box'>
                    <View className='button' onClick={this.saveButtonHandler.bind(this)}>
                        <Button size='mini' className='button-orange'>保存</Button>
                    </View>
                    <View className='button' onClick={this.saveAndNewButton.bind(this)}>
                        <Button size='mini' className='button-green'>保存并新增</Button>
                    </View>
                    {/* <View className='button'>

                        <Button  className='button-a' size='mini' className='button-orange'>保存并新增</Button>
                    </View> */}
                    <View className='button' onClick={this.goToMyDemSupPage.bind(this)}>
                        <Button size='mini' className='button-green'>我的供求</Button>
                    </View>
                    <View className='button' onClick={this.deleteButtonHandler.bind(this)}>
                        <Button size='mini' className='button-dark-red'>删除</Button>
                    </View>
                </View>
                <CopyrightComponent></CopyrightComponent>


            </View>
        )
    }
}

export default MyDemandSupplyEdit
